function zeile = omparameteraendern(parameterfile,parameter,werte)
%-----------------------------------------------------------------------------------------
%Funktion zum Finden und optinalen ndern von Parametern bzw. Eintrgen innerhalb eines 
%OpenModelica Parameterfiles.
%
%SYNTAX:    zeile = omparameteraendern(parameterfile,parameter,werte)
%
%mit:       parameterfile = NAME (String) des Parameterfiles
%           parameter     = cell Array mit den Namen der Parameter bzw. Eintrge
%                           ACHTUNG: Das cell array darf nur den Namen des Parameters als
%                           String enthalten. Bsp. Parameter m und g
%                           zeile = omparameterfinden(parameterfile,{'m','g'},[10,9.81])
%           werte         = (optional) double array mi den Werten der Parameter die 
%                           gendert werden sollen. Wenn werte nicht existiert werden
%                           keine Parameter gendert
%
%           zeile         = Indices der Zeilen des Parameterfiles, in denen die gefundenen
%                           Parameter stehen
%
%(c) Hamadeh, April   2008
%-----------------------------------------------------------------------------------------
%%
if ~iscell(parameter)
    fprintf('\nDer Eingangsparameter parameter muss ein cell array sein!\n');
    zeile = [];
    return
end

if exist('werte','var')
    if length(parameter)~=length(werte)
        fprintf('\nACHTUNG: Anzahl Parameter ~= Anzahl Werte!\nEs wurden keine Parameter gendert!\n\n');
        zeile = [];
        return
    end
    aendern = 1;
else
    aendern = 0;
end

fid = fopen(parameterfile,'r');
n     = 0;
tline = 0;
while tline ~= -1
    n = n+1;
    tline = fgets(fid);
    parametercell{n} = tline;
end
fclose(fid);

anz1 = length(parameter);
for m = 1:anz1
    %     parameter1{n} = ['// ',parameter{n},char(10)]
    parameter1{m} = ['// ',parameter{m}];
    index1{m} = stringincellarray(parametercell,parameter1{m});
    zeile(m)  = find(index1{m}~=0,1);
    spalte(m) = strfind(parametercell{zeile(m)},'//');
    
    % Wird nur ausgefhrt, wenn Parameter gendert werden sollen
    if aendern == 1
        % Zusammensetzen des neuen Parameterstring cell arrays
        parametercell{zeile(m)} = [num2str(werte(m)),' ', parametercell{zeile(m)}(spalte(m):end)];
    end
end

% % Umschreiben des Parameterfiles mit den genderten Parametern
if aendern == 1
    fid = fopen(parameterfile,'w');
    for o = 1:n-1
        fprintf(fid,parametercell{o});
    end
    fclose(fid);
end
